@@ -222,7 +222,7 @@ class BaseExperiment:
         self.logger = None # Pointer for logger.
         self.fit_or_cv = "FIT" 
         self.saved_model_types = {}
-        
+        self.hyperparameter_setting = []
         self.X_train = self.y_train = None # Pointer for training data.
 
         self._create_folder(self.project_path)
@@ -1010,7 +1010,12 @@ class BaseExperiment:
         hparams_str = "default_hyperparameters" if hparams_str == "" else hparams_str
         
         model_metadata = f"{model.__class__.__name__}-{hparams_str}" 
+        if len(model_metadata) >= 255:
+            if hparams not in self.hyperparameter_setting:
+                self.hyperparameter_setting.append(hparams)
 
+            hparams_str = f"hyperparameter_setting-{self.hyperparameter_setting.index(hparams)}"
+            model_metadata = f"{model.__class__.__name__}-{hparams_str}" 
         return model_metadata
    
     def get_hparams(self, model):
