@@ -1,4 +1,4 @@
-from astrape.models.models_lightning import MLP, ContractingMLP, CustomMLP, VGG, UNet, PixelCNN
+from astrape.models.models_lightning import MLP, ContractingMLP, CustomMLP, VGG, UNet, PixelCNN, ResNet18
 from astrape.models.model_buildingblocks import DoubleConv, Down, Up
 from astrape.utilities.utils_lightning import set_default_parameters
 
@@ -8,6 +8,7 @@ __all__ = [
     'ContractingMLP', 
     'CustomMLP', 
     'PixelCNN',
+    'ResNet18',
     'VGG', 
     'UNet', 
     'DoubleConv', 
